<?php
	/**
	 * This loop is used to create items for the portfolio archives and also the homepage template.
	 * Any custom functions prefaced with ebor_ are found in /ebor_framework/theme_functions.php
	 * First let's declare $post so that we can easily grab everthing needed.
	 */
	 global $post;
	 
	 /**
	  * Next, we need to grab the featured image URL of this post, so that we can trim it to the correct size for the chosen size of this post.
	  */
	 $url = wp_get_attachment_image_src( get_post_thumbnail_id($post->ID), 'full');
	 
	 /**
	  * Leave this portfolio item out if we didn't find a featured image.
	  */
	 if(!( $url[0] ))
	 	return false;
	 	
	 $size = esc_html(get_post_meta($post->ID, '_ebor_masonry_layout', 1));
	 if( '' == $size || false == $size || !(isset($size)) )
	 	$size = 'normal';
	 
	 if( 'normal' == $size ){
	 	$image = aq_resize($url[0], '285','190',1);
	 } elseif( 'width2' == $size ) {
	 	$image = aq_resize($url[0], '580','190',1);
	 } elseif( 'height2' == $size ) {
	 	$image = aq_resize($url[0], '285','390',1);
	 } elseif( 'width2 height2' == $size ) {
	 	$image = aq_resize($url[0], '580','390',1);
	 }
	 
	 if(!( $image ))
	 	$image = $url[0];
	 	
	 if( get_post_format() == 'video' ){
	 	$videos = get_post_meta( $post->ID, '_ebor_videos', true );
	 	$url[0] = esc_url($videos[0]['_ebor_the_oembed']);
	 }
	 
	 $attachments = get_post_meta($post->ID, '_ebor_gallery_images', 1); 
?>

<div class="item <?php echo $size; ?> <?php echo ebor_the_terms('portfolio_category', ' ', 'slug'); ?>">
	<figure>
		<a href="<?php echo $url[0]; ?>" class="fancybox-media" data-rel="grid-portfolio" data-title-id="title-<?php echo $post->ID; ?>">
			<?php 
				the_title('<div class="text-overlay"><div class="info"><span>', '</span></div></div>');
			?>
			<img src="<?php echo $image; ?>" alt="<?php the_title(); ?>" /> 
		</a>
	</figure>
	<?php 
		the_title('<div id="title-'. $post->ID .'" class="info hidden"><h2>', '</h2>'. wpautop(get_the_excerpt()) .'</div>');
		
		/**
		* If we found items, output the gallery.
		* $before and $after change depending on the gallery chosen.
		*/
		if ( is_array( $attachments ) ){
			foreach( $attachments as $id => $content ){
				$url = wp_get_attachment_image_src( $id, 'full' );
				echo '<a href="'. $url[0] .'" class="fancybox-media" data-rel="grid-portfolio" style="display:none;"></a>';
			}
		}
	?>
</div>