<?php

class AQ_Portfolio_Block extends AQ_Block {
	
	//set and create block
	function __construct() {
		$block_options = array(
			'name' => 'Portfolio',
			'size' => 'span12',
			'resizable' => 0,
			'block_description' => 'Add a feed of Portfolio posts to the page.',
			'block_category' => 'feeds',
			'block_icon' => '<i class="fa fa-fw fa-paint-brush"></i>'
		);
		parent::__construct('aq_portfolio_block', $block_options);
	}//end construct
	
	function form($instance) {
		$defaults = array(
			'type' => 'classic',
			'pppage' => '999',
			'filter' => 'all',
			'show_filter' => 1
		);
		
		$instance = wp_parse_args($instance, $defaults);
		extract($instance);
		
		$args = array(
			'orderby'                  => 'name',
			'hide_empty'               => 0,
			'hierarchical'             => 1,
			'taxonomy'                 => 'portfolio_category'
		); 
			
		$filter_options = get_categories( $args );
		
		$portfolio_types = array(
			'classic' => 'Classic Masonry',
			'masonry' => 'Fixed Masonry',
			'full' => 'Full Width',
			'classic-lightbox' => 'Classic Masonry Lightbox',
			'masonry-lightbox' => 'Fixed Masonry Lightbox',
			'full-lightbox' => 'Full Width Lightbox'
		);
	?>
		
		<p class="description">If using the full width layout, don't nest this in a page section block.</p>
		
		<hr />
		
		<p class="description">Title <code>Optiional</code></p>
		<?php echo aq_field_input('title', $block_id, $title, $size = 'full') ?>
		
		<p class="description">Portfolio Style</p>
		<?php echo aq_field_select('type', $block_id, $portfolio_types, $type) ?>
		
		<p class="description">Load how many items? 999 for all. <code>Note: The Portfolio is not Paged</code></p>
		<?php echo aq_field_input('pppage', $block_id, $pppage, $size = 'full', $type = 'number') ?>
		
		<p class="description">Show a specific portfolio category?</p>
		<?php echo ebor_portfolio_field_select('filter', $block_id, $filter_options, $filter) ?>
		
		<hr />
		
		<div class="ebor-checkbox cf">
			<?php echo aq_field_checkbox('show_filter', $block_id, $show_filter) ?>
			<p class="description">Show Portfolio Filters?</p>
		</div>
		
	<?php
	}//end form
	
	function block($instance) {
		extract($instance);
		
		/**
		 * Initial query args
		 */
		$query_args = array(
			'post_type' => 'portfolio',
			'posts_per_page' => $pppage
		);
		
		/**
		 * If we're choosing just 1 category, add more args.
		 * GRAB ALL THE ARGS!
		 */
		if (!( $filter == 'all' )) {
			if( function_exists( 'icl_object_id' ) ){
				$filter = (int)icl_object_id( $filter, 'portfolio_category', true);
			}
			$query_args['tax_query'] = array(
				array(
					'taxonomy' => 'portfolio_category',
					'field' => 'id',
					'terms' => $filter
				)
			);
		}
		
		/**
		 * Finally, here's the query.
		 */
		$block_query = new WP_Query( $query_args );
		
		/**
		 * Now let's grab categories for the animated portfolio filter buttons
		 */
		$cats = ( $filter == 'all' ) ? get_categories('taxonomy=portfolio_category') : get_categories('taxonomy=portfolio_category&exclude='. $filter .'&child_of='. $filter);
		
		if( 'classic' == $type ) :
	?>
		
		<div class="portfolio classic-masonry">
			
			<?php 
				if( $title )
					echo '<h3 class="section-title pull-left">'. htmlspecialchars_decode($title) .'</h3>';
					
				if( 1 == $show_filter )
					echo ebor_portfolio_filters($cats); 
			?>
			<div class="clearfix"></div>
			
			<div class="isotope items">
				<?php 
					if ( $block_query->have_posts() ) : while ( $block_query->have_posts() ) : $block_query->the_post();
						
						/**
						 * Get blog posts by blog layout.
						 */
						get_template_part('loop/content-portfolio', 'classic');
					
					endwhile;	
					else : 
						
						/**
						 * Display no posts message if none are found.
						 */
						get_template_part('loop/content','none');
						
					endif;
					wp_reset_query();
				?>
			</div>
			
		</div>
		
	<?php elseif( 'masonry' == $type ) : ?>
	
		<div class="portfolio fix-portfolio">
		
			<?php 
				if( $title )
					echo '<h3 class="section-title pull-left">'. htmlspecialchars_decode($title) .'</h3>';
					
				if( 1 == $show_filter )
					echo ebor_portfolio_filters($cats); 
			?>
			<div class="clearfix"></div>
		
			<div class="isotope items">
				<?php 
					if ( $block_query->have_posts() ) : while ( $block_query->have_posts() ) : $block_query->the_post();
						
						/**
						 * Get blog posts by blog layout.
						 */
						get_template_part('loop/content-portfolio', 'masonry');
					
					endwhile;	
					else : 
						
						/**
						 * Display no posts message if none are found.
						 */
						get_template_part('loop/content','none');
						
					endif;
					wp_reset_query();
				?>
			</div>
			
		</div><!-- /.portfolio -->
	
	<?php elseif( 'full' == $type ) : ?>
		
		<div class="portfolio full-portfolio">
		
			<div class="container">
				<?php 
					if( $title )
						echo '<h3 class="section-title pull-left">'. htmlspecialchars_decode($title) .'</h3>';
						
					if( 1 == $show_filter )
						echo ebor_portfolio_filters($cats); 
				?>
			</div>
			<div class="clearfix"></div>
			
			<div class="isotope items">
				<div class="grid-sizer"></div>
				<?php 
					if ( $block_query->have_posts() ) : while ( $block_query->have_posts() ) : $block_query->the_post();
						
						/**
						 * Get blog posts by blog layout.
						 */
						get_template_part('loop/content-portfolio', 'full');
					
					endwhile;	
					else : 
						
						/**
						 * Display no posts message if none are found.
						 */
						get_template_part('loop/content','none');
						
					endif;
					wp_reset_query();
				?>
			</div>
			
		</div>
		
	<?php elseif( 'classic-lightbox' == $type ) : ?>
		
		<div class="portfolio classic-masonry">
		
			<?php 
				if( $title )
					echo '<h3 class="section-title pull-left">'. htmlspecialchars_decode($title) .'</h3>';
					
				if( 1 == $show_filter )
					echo ebor_portfolio_filters($cats); 
			?>
			<div class="clearfix"></div>
			
			<div class="isotope items">
				<?php 
					if ( $block_query->have_posts() ) : while ( $block_query->have_posts() ) : $block_query->the_post();
						
						/**
						 * Get blog posts by blog layout.
						 */
						get_template_part('loop/content-portfolio', 'classic-lightbox');
					
					endwhile;	
					else : 
						
						/**
						 * Display no posts message if none are found.
						 */
						get_template_part('loop/content','none');
						
					endif;
					wp_reset_query();
				?>
			</div>
			
		</div>
		
	<?php elseif( 'masonry-lightbox' == $type ) : ?>
	
		<div class="portfolio fix-portfolio">
		
			<?php 
				if( $title )
					echo '<h3 class="section-title pull-left">'. htmlspecialchars_decode($title) .'</h3>';
					
				if( 1 == $show_filter )
					echo ebor_portfolio_filters($cats); 
			?>
			<div class="clearfix"></div>
		
			<div class="isotope items">
				<?php 
					if ( $block_query->have_posts() ) : while ( $block_query->have_posts() ) : $block_query->the_post();
						
						/**
						 * Get blog posts by blog layout.
						 */
						get_template_part('loop/content-portfolio', 'masonry-lightbox');
					
					endwhile;	
					else : 
						
						/**
						 * Display no posts message if none are found.
						 */
						get_template_part('loop/content','none');
						
					endif;
					wp_reset_query();
				?>
			</div>
			
		</div><!-- /.portfolio -->
	
	<?php elseif( 'full-lightbox' == $type ) : ?>
		
		<div class="portfolio full-portfolio">
		
			<div class="container">
				<?php 
					if( $title )
						echo '<h3 class="section-title pull-left">'. htmlspecialchars_decode($title) .'</h3>';
						
					if( 1 == $show_filter )
						echo ebor_portfolio_filters($cats); 
				?>
			</div>
			<div class="clearfix"></div>
			
			<div class="isotope items">
				<div class="grid-sizer"></div>
				<?php 
					if ( $block_query->have_posts() ) : while ( $block_query->have_posts() ) : $block_query->the_post();
						
						/**
						 * Get blog posts by blog layout.
						 */
						get_template_part('loop/content-portfolio', 'full-lightbox');
					
					endwhile;	
					else : 
						
						/**
						 * Display no posts message if none are found.
						 */
						get_template_part('loop/content','none');
						
					endif;
					wp_reset_query();
				?>
			</div>
			
		</div>
		
	<?php
		endif;
		
	}//end block
	
}//end class